<?php

namespace SkyVerge\WooCommerce\Bambora\Blocks;

use SkyVerge\WooCommerce\Bambora\Gateway\Credit_Card;
use SkyVerge\WooCommerce\Bambora\Plugin;
use SkyVerge\WooCommerce\PluginFramework\v5_12_1\Payment_Gateway\Blocks\Gateway_Checkout_Block_Integration;
use SkyVerge\WooCommerce\PluginFramework\v5_12_1\SV_WC_Payment_Gateway;

/**
 * Checkout block integration handler.
 *
 * @since 2.9.0
 *
 * @property Plugin $plugin
 * @property Credit_Card $gateway
 */
class Credit_Card_Checkout_Block_Integration extends Gateway_Checkout_Block_Integration {


	/**
	 * Constructor.
	 *
	 * @since 2.9.0
	 *
	 * @param Plugin $plugin
	 * @param Credit_Card $gateway
	 */
	public function __construct( Plugin $plugin, Credit_Card $gateway ) {

		parent::__construct( $plugin, $gateway );

		$this->add_main_script_dependency( Credit_Card::CUSTOM_CHECKOUT_SCRIPT_HANDLE );
	}


	/**
	 * Adds payment method data for the checkout block.
	 *
	 * @since 2.9.0
	 *
	 * @param array<string, mixed> $payment_method_data
	 * @param Credit_Card $gateway
	 * @return array<string, mixed>
	 */
	public function add_payment_method_data( array $payment_method_data, SV_WC_Payment_Gateway $gateway ) : array {

		$test_cards = [];

		foreach ( $gateway->get_test_cards() as $test_card_number => $test_card_label ) {
			$test_cards[] = [
				'number' => $test_card_number,
				'label'  => $test_card_label,
			];
		}

		$payment_method_data['gateway'] = array_merge(
			$payment_method_data['gateway'] ?: [],
			[
				'merchant_id'  => $gateway->get_merchant_id(),
				'test_cards'   => $test_cards,
				'field_styles' => $gateway->get_checkout_field_styles( 'block' ),
			]
		);

		$payment_method_data['flags'] = array_merge(
			$payment_method_data['flags'] ?: [],
			[
				'billing_email_required' => $gateway->billing_email_is_required(),
			]
		);

		return $payment_method_data;
	}


	/**
	 * {@inheritDoc}
	 *
	 * Overrides the method to register dependency script in-advance.
	 *
	 * @since 2.9.3
	 */
	public function get_payment_method_script_handles() : array
	{
		$this->gateway->registerGatewayAssets();

		return parent::get_payment_method_script_handles();
	}
}
